==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Block/InsertBlockItem/ts/InsertBlockItem_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>InsertBlockItem</name>
    <message>
        <location filename="../InsertBlockItem.js" line="+88"/>
        <source>Cannot import file from URL: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Adjusted invalid block name to &apos;%1&apos;</source>
        <translation>無効なブロック名は&apos;%1&apos;に調整されました</translation>
    </message>
    <message>
        <location line="+55"/>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../InsertBlockItem.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>回転:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate pasted entities&lt;br&gt;by this angle</source>
        <translation>貼り付けエンティティを回転&lt;br&gt;この角度で</translation>
    </message>
    <message>
        <location line="+90"/>
        <source>Scale:</source>
        <translation>縮尺:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale pasted entities&lt;br&gt;by this factor</source>
        <translation>貼り付けエンティティを拡縮&lt;br&gt;この係数で</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Flip pasted entities&lt;br&gt;horizontally</source>
        <translation>貼り付けエンティティを反転&lt;br&gt;水平</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Flip pasted entities&lt;br&gt;vertically</source>
        <translation>貼り付けエンティティを反転&lt;br&gt;垂直</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Overwrite existing layers&lt;br&gt;in drawing with&lt;br&gt;layers from clipboard</source>
        <translation>クリップボードから図面の&lt;br&gt;既存の画層に上書き</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite layers</source>
        <translation>画層に上書き</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing blocks&lt;br&gt;in drawing with&lt;br&gt;blocks from clipboard</source>
        <translation>クリップボードから図面の&lt;br&gt;既存のブロックに上書き</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite blocks</source>
        <translation>ブロックに上書き</translation>
    </message>
    <message>
        <location filename="../InsertBlockItemInit.js" line="+2"/>
        <source>&amp;Insert Block</source>
        <translation>&amp;I ブロック挿入</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Block/InsertBlockItem/ts/InsertBlockItem_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>InsertBlockItem</name>
    <message>
        <location filename="../InsertBlockItem.js" line="+102"/>
        <source>Cannot import file from URL: </source>
        <translation>次のURLからはファイルをインポートできません:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Adjusted invalid block name to &apos;%1&apos;</source>
        <translation>無効なブロック名は&apos;%1&apos;に調整されました</translation>
    </message>
    <message>
        <location line="+62"/>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../InsertBlockItem.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>回転:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate pasted entities&lt;br&gt;by this angle</source>
        <translation>貼り付けエンティティを回転&lt;br&gt;この角度で</translation>
    </message>
    <message>
        <location line="+100"/>
        <source>Scale:</source>
        <translation>縮尺:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale pasted entities&lt;br&gt;by this factor</source>
        <translation>貼り付けエンティティを拡縮&lt;br&gt;この係数で</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Flip pasted entities&lt;br&gt;horizontally</source>
        <translation>貼り付けエンティティを反転&lt;br&gt;水平</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Flip pasted entities&lt;br&gt;vertically</source>
        <translation>貼り付けエンティティを反転&lt;br&gt;垂直</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Overwrite existing layers&lt;br&gt;in drawing with&lt;br&gt;layers from clipboard</source>
        <translation>クリップボードから図面の&lt;br&gt;既存の画層に上書き</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite layers</source>
        <translation>画層に上書き</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing blocks&lt;br&gt;in drawing with&lt;br&gt;blocks from clipboard</source>
        <translation>クリップボードから図面の&lt;br&gt;既存のブロックに上書き</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite blocks</source>
        <translation>ブロックに上書き</translation>
    </message>
    <message>
        <location filename="../InsertBlockItemInit.js" line="+2"/>
        <source>&amp;Insert Block</source>
        <translation>&amp;I ブロック挿入</translation>
    </message>
</context>
</TS>
